@@ -10,7 +10,7 @@ pub async fn run() -> std::io::Result<()> {
     let conf = get_configuration(None).await.unwrap();
     let addr = conf.leptos_options.site_addr;
 
-    log::info!("serving at {addr}");
+    warn!("serving at {addr}");
 
     // Generate the list of routes in your Leptos App
     let routes = generate_route_list(|| view! { <App /> });
