@@ -1,6 +1,7 @@
 use actix_web::*;
 use leptos::*;
 use leptos_actix::{generate_route_list, LeptosRoutes};
+use tracing::*;
 
 fn app() -> impl IntoView {
     use app_package::*;
@@ -17,7 +18,7 @@ pub async fn main() -> std::io::Result<()> {
     let conf = get_configuration(None).await.unwrap();
     let addr = conf.leptos_options.site_addr;
 
-    log::info!("serving at {addr}");
+    info!("serving at {addr}");
 
     // Generate the list of routes in your Leptos App
     let routes = generate_route_list(app);
