@@ -1,8 +1,10 @@
 use crate::config::Project;
-use crate::ext::anyhow::Context;
-use anyhow::Result;
+use crate::ext::color_eyre::CustomWrapErr;
+use crate::internal_prelude::*;
 use base64ct::{Base64UrlUnpadded, Encoding};
 use camino::Utf8PathBuf;
+use color_eyre::eyre::ContextCompat;
+use color_eyre::Result;
 use md5::{Digest, Md5};
 use std::collections::HashMap;
 use std::fs;
@@ -11,7 +13,7 @@ use std::fs;
 pub fn add_hashes_to_site(proj: &Project) -> Result<()> {
     let files_to_hashes = compute_front_file_hashes(proj).dot()?;
 
-    log::debug!("Hash computed: {files_to_hashes:?}");
+    debug!("Hash computed: {files_to_hashes:?}");
 
     let renamed_files = rename_files(&files_to_hashes).dot()?;
 
@@ -25,9 +27,9 @@ pub fn add_hashes_to_site(proj: &Project) -> Result<()> {
         proj.hash_file
             .abs
             .parent()
-            .with_context(|| format!("no parent dir for {}", proj.hash_file.abs))?,
+            .wrap_err_with(|| format!("no parent dir for {}", proj.hash_file.abs))?,
     )
-    .with_context(|| format!("Failed to create parent dir for {}", proj.hash_file.abs))?;
+    .wrap_err_with(|| format!("Failed to create parent dir for {}", proj.hash_file.abs))?;
 
     fs::write(
         &proj.hash_file.abs,
@@ -37,25 +39,25 @@ pub fn add_hashes_to_site(proj: &Project) -> Result<()> {
                 .js_file
                 .dest
                 .extension()
-                .ok_or(anyhow::anyhow!("no extension"))?,
+                .ok_or(eyre!("no extension"))?,
             files_to_hashes[&proj.lib.js_file.dest],
             proj.lib
                 .wasm_file
                 .dest
                 .extension()
-                .ok_or(anyhow::anyhow!("no extension"))?,
+                .ok_or(eyre!("no extension"))?,
             files_to_hashes[&proj.lib.wasm_file.dest],
             proj.style
                 .site_file
                 .dest
                 .extension()
-                .ok_or(anyhow::anyhow!("no extension"))?,
+                .ok_or(eyre!("no extension"))?,
             files_to_hashes[&proj.style.site_file.dest]
         ),
     )
-    .with_context(|| format!("Failed to write hash file to {}", proj.hash_file.abs))?;
+    .wrap_err_with(|| format!("Failed to write hash file to {}", proj.hash_file.abs))?;
 
-    log::debug!("Hash written to {}", proj.hash_file.abs);
+    debug!("Hash written to {}", proj.hash_file.abs);
 
     Ok(())
 }
@@ -124,13 +126,13 @@ fn rename_files(
 
         new_path.set_file_name(format!(
             "{}.{}.{}",
-            path.file_stem().ok_or(anyhow::anyhow!("no file stem"))?,
+            path.file_stem().ok_or(eyre!("no file stem"))?,
             hash,
-            path.extension().ok_or(anyhow::anyhow!("no extension"))?,
+            path.extension().ok_or(eyre!("no extension"))?,
         ));
 
         fs::rename(path, &new_path)
-            .with_context(|| format!("Failed to rename {path} to {new_path}"))?;
+            .wrap_err_with(|| format!("Failed to rename {path} to {new_path}"))?;
 
         old_to_new_paths.insert(path.clone(), new_path);
     }
