@@ -5,6 +5,7 @@ use tokio::{
 };
 
 use crate::compile::{Change, ChangeSet};
+use crate::internal_prelude::*;
 
 lazy_static::lazy_static! {
   static ref ANY_INTERRUPT: broadcast::Sender<()> = broadcast::channel(10).0;
@@ -36,7 +37,7 @@ impl Interrupt {
     pub async fn clear_source_changes() {
         let mut ch = SOURCE_CHANGES.write().await;
         ch.clear();
-        log::trace!("Interrupt source changed cleared");
+        trace!("Interrupt source changed cleared");
     }
 
     pub fn send_all_changed() {
@@ -58,9 +59,9 @@ impl Interrupt {
 
     fn send_any() {
         if let Err(e) = ANY_INTERRUPT.send(()) {
-            log::error!("Interrupt error could not send due to: {e}");
+            error!("Interrupt error could not send due to: {e}");
         } else {
-            log::trace!("Interrupt send done");
+            trace!("Interrupt send done");
         }
     }
 
@@ -75,7 +76,7 @@ impl Interrupt {
     pub fn run_ctrl_c_monitor() -> JoinHandle<()> {
         tokio::spawn(async move {
             signal::ctrl_c().await.expect("failed to listen for event");
-            log::info!("Leptos ctrl-c received");
+            info!("Leptos ctrl-c received");
             Interrupt::request_shutdown().await;
         })
     }
