@@ -1,3 +1,4 @@
+use crate::internal_prelude::*;
 use leptos_hot_reload::diff::Patches;
 use tokio::sync::broadcast;
 
@@ -17,12 +18,12 @@ pub struct ReloadSignal {}
 impl ReloadSignal {
     pub fn send_full() {
         if let Err(e) = RELOAD_CHANNEL.send(ReloadType::Full) {
-            log::error!(r#"Error could not send reload "Full" due to: {e}"#);
+            error!(r#"Error could not send reload "Full" due to: {e}"#);
         }
     }
     pub fn send_style() {
         if let Err(e) = RELOAD_CHANNEL.send(ReloadType::Style) {
-            log::error!(r#"Error could not send reload "Style" due to: {e}"#);
+            error!(r#"Error could not send reload "Style" due to: {e}"#);
         }
     }
 
@@ -30,10 +31,10 @@ impl ReloadSignal {
         match serde_json::to_string(view_patches) {
             Ok(data) => {
                 if let Err(e) = RELOAD_CHANNEL.send(ReloadType::ViewPatches(data)) {
-                    log::error!(r#"Error could not send reload "View Patches" due to: {e}"#);
+                    error!(r#"Error could not send reload "View Patches" due to: {e}"#);
                 }
             }
-            Err(e) => log::error!(r#"Error could not send reload "View Patches" due to: {e}"#),
+            Err(e) => error!(r#"Error could not send reload "View Patches" due to: {e}"#),
         }
     }
 
